Software support
----------------

* We announce major and minor package updates via Twitter.  Follow the hashtag `#pybliometrics <https://twitter.com/hashtag/pybliometrics>`_ to be the first to learn of software updates.
* The best place to ask questions on how to do things is StackOverflow.  Simply tag your question with `pybliometrics <https://stackoverflow.com/questions/tagged/pybliometrics>`_.  There's already a bunch of questions (with answers) out there!
* In the GitHub repository, you can create issues and report bugs, request features, or, even better, submit your own pull requests.  Read more about contributing :doc:`here <../contributing>`.
